@@ -8,7 +8,7 @@
 #define GLIBMM_MAJOR_VERSION 2
 
 /* Minor version number of glibmm. */
-#define GLIBMM_MINOR_VERSION 78
+#define GLIBMM_MINOR_VERSION 80
 
 /* Micro version number of glibmm. */
 #define GLIBMM_MICRO_VERSION 1
@@ -101,6 +101,26 @@
 #define GLIBMM_HAVE_ALLOWS_STATIC_INLINE_NPOS 1
 #endif
 
+#ifndef GLIBMM_SIZEOF_WCHAR_T
+#define GLIBMM_SIZEOF_WCHAR_T 2
+#endif
+
+#ifndef GLIBMM_SIZEOF_SHORT
+#define GLIBMM_SIZEOF_SHORT 2
+#endif
+
+#ifndef GLIBMM_SIZEOF_INT
+#define GLIBMM_SIZEOF_INT 4
+#endif
+
+#ifndef GLIBMM_SIZEOF_LONG
+#define GLIBMM_SIZEOF_LONG 4
+#endif
+
+#ifndef GLIBMM_SIZEOF_LONG_LONG
+#define GLIBMM_SIZEOF_LONG_LONG 8
+#endif
+
 #endif /* GLIBMM_MSC */
 
 /* Enable DLL-specific stuff only when not building a static library */
